function C = tot_effects_cent_u(A,alpha)

%   Total Effects Centrality
%
%   C = tot_effects_cent_u(A,alpha);
%
%   Total effects centrality reflects the average influence of a node on
%   all other nodes.  
%   
%   Input:  A,     undirected, weighted/binary connection matrix
%           alpha, weight for inter-nodal influences (default = 0.999)
%
%   Output: C,     total effects centrality
%
%
%   Reference: Friedkin NE. (1991), Amer J Sociol 96, 1478-1504.
%
%   Jeff Spielberg, University of Delaware

%   Modification History:
%   October 2016: Original

if nargin<2                                    % If alpha not specified
    alpha = 0.999;                             % Set close to 1
end
n = size(A,1);                                 % Number of nodes
A = A.*(A>0).*(1-eye(n));                      % Ensure that all weights are positive and the diagonal is cleared
W = A./repmat(sum(A,2),1,n);                   % Compute influence network
V = offdiag(inv(eye(n)-(alpha*W)).*(1-alpha)); % Compute total influence effects matrix
C = sum(V,1)'./(n-1);                          % Compute total effects centrality
